#  Depth-invariant processing algorithm to produce a depth-invariant index image
#  from bands 3 (green: 531.1-543.5 nm) and 4 (green: 571.9-584.3 nm) of a CASI image
#
#  Input data needed are:
#
#  1) The deep water reflectances in each band, Lsi (= average deep water reflectance - 2 standard
#      deviations). Entered as constants deepwater3 and deepwater4.
#
#  2) The ratio of the attenuation coefficients k3/k4. Entered as constant k3k4ratio.
#
#  Note : The output image should be Float (32 bit) and masked areas should be left as zero.

	CONST deepwater3 = 344 ;
	CONST deepwater4 = 186 ;
	CONST k3k4ratio = 0.73393 ;
	CONST casiband3 = @1 ;
                CONST casiband4 = @2 ;

	IF (casiband3 > 0)  ln(casiband3 - deepwater3) - ( k3k4ratio * ln(casiband4 - deepwater4) ) 
	ELSE 0 ;
